Installation instructions
=========================

BioSimulators-COPASI is available as a command-line program and as a command-line program encapsulated into a Docker image.

Command-line program
--------------------

After installing `Python <https://www.python.org/downloads/>`_ (>= 3.7) and `pip <https://pip.pypa.io/>`_, run the following command to install BioSimulators-COPASI:

.. code-block:: text

    pip install biosimulators-copasi


Docker image with a command-line entrypoint
-------------------------------------------

After installing `Docker <https://docs.docker.com/get-docker/>`_, run the following command to install the Docker image for BioSimulators-COPASI:

.. code-block:: text

    docker pull ghcr.io/biosimulators/copasi
